/*
 * interrupts.c - arm exception handling
 *
 * author: hackbard@hackdaworld.org
 *
 */

#include "interrupts.h"

/*
 * functions
 */

void interrupt_set_default_callback(void *callback) {

	VICDefVectAddr=(u32)callback;
	
}

void interrupt_clear(u8 src_number) {

	VICIntEnClear=(1<<src_number);

}

int interrupt_enable(u8 src_number,u8 mode,u8 priority,void *callback) {

	/* check whether this ir source is allready assigned */
	if(VICIntEnable&(1<<src_number))
		return INTERRUPT_EINUSE;

	/* force interrupt */
	VICIntEnable=(1<<src_number);

	switch(mode) {
		case INTERRUPT_FIQ:
			VICIntSelect|=(1<<src_number);
			break;
		case INTERRUPT_VIRQ:
			
		case INTERRUPT_IRQ:
		case default:
	}

	return INTERRUPT_SET;
}

/*
 * the actual exception handlers (as defined in startup.s)
 */

// reset
void interrupt_handler_reset(void) {
}

// undefined instruction
void interrupt_handler_undef_instruction(void) {
}

// software interrupt
void interrupt_handler_soft_ir(void) {
}

// prefetch abort
void interrupt_handler_prefetch_abort(void) {
}

// data abort
void interrupt_handler_data_abort(void) {
}

// fiq
void interrupt_handler_fiq(void) {
}

